@@ -58,9 +58,9 @@ class DatabaseParser:
         if item_block["type"] == "title":  # title
             item_ret = self.base_parser.title_parser(item_block, page_id, parser_type=self.parser_type)
         elif item_block["type"] == "multi_select":  # multi_select
-            item_ret = self.base_parser.multi_select_parser(item_block)
+            item_ret = self.base_parser.multi_select_parser(item_block, parser_type=self.parser_type)
         elif item_block["type"] == "select":
-            item_ret = self.base_parser.select_parser(item_block)
+            item_ret = self.base_parser.select_parser(item_block, parser_type=self.parser_type)
         elif item_block["type"] == "rich_text":
             item_ret = self.base_parser.rich_text_parser(item_block, parser_type=self.parser_type)
         elif item_block["type"] == "url":
@@ -79,8 +79,22 @@ class DatabaseParser:
             item_ret = self.base_parser.number_parser(item_block)
         elif item_block["type"] == "files":
             item_ret = self.base_parser.files_parser(item_block, parser_type=self.parser_type)
+        elif item_block["type"] == "relation":
+            item_ret = self.base_parser.relation_parser(item_block)
         elif item_block["type"] == "rollup":
-            item_ret = self.base_parser.rollup_parser(item_block)
+            # rollup类型单独解析
+            rollup_block = item_block["rollup"]
+            if "array" in rollup_block:
+                # 列表的解析
+                for rollup_item in rollup_block["array"]:
+                    if item_ret != "":
+                        item_ret += ","
+                    item_ret += self.__parser_item(rollup_item, "")
+            else:
+                # 单个内容的解析
+                item_ret += self.__parser_item(rollup_block, "")
+        elif item_block["type"] == "formula":
+            item_ret = self.base_parser.formula_parser(item_block)
         elif item_block["type"] == "created_time":
             item_ret = self.base_parser.created_time_parser(item_block)
         elif item_block["type"] == "last_edited_time":
@@ -90,10 +104,50 @@ class DatabaseParser:
         elif item_block["type"] == "last_edited_by":
             item_ret = self.base_parser.last_edited_by_parser(item_block)
         else:
+            item_ret = "[unknown_type:" + item_block["type"] + "]"
             common_op.debug_log("[ISSUE] unknown properties type:" + item_block["type"], level=NotionDump.DUMP_MODE_DEFAULT)
-
+        if item_ret is None:
+            item_ret = ""
         return item_ret
 
+    def database_to_md(self, page_properties, new_id=None):
+        if page_properties is None:
+            return "", ""
+        # 获取属性部分
+        if "properties" not in page_properties:
+            return "", ""
+        page_properties = page_properties["properties"]
+
+        # 设置基础解析器的id
+        if new_id is not None:
+            self.base_parser.set_new_id(new_id)
+
+        # 数据库是空的，直接返回完事
+        if len(page_properties) == 0:
+            return "", ""
+
+        properties_md = ""
+        # print(page_properties.keys())
+        p_title = ""
+        p_title_name = ""
+        for p_name in list(page_properties.keys())[::-1]:
+            p_value = self.__parser_item(page_properties[p_name], page_id="").replace('\n', '<br>')
+            if page_properties[p_name]["type"] == "title":
+                p_title = p_value
+                p_title_name = p_name
+                continue
+            # print(p_value, p_name)
+            properties_md += "\n" + "|" + str(p_name) + "|" + str(p_value) + "|"
+        if p_title != "" or p_title_name != "":
+            properties_md = "|" + p_title_name + "|" + p_title + "|\n|---|---|" + properties_md
+        else:
+            properties_md = "|KEY|VALUE|\n|---|---|" + properties_md
+
+        if len(page_properties) == 1:
+            return "", p_title
+        else:
+            return properties_md, p_title
+
     # 格式化存储，这里是临时文件存在方式（在外面转成数据库，或者最终输出CSV的格式）
     def database_to_file(self, database_handle, col_name_list=None, new_id=None):
         page_list = database_handle.get("results")
