@@ -3,7 +3,8 @@
 # mail:geniusrabbit@qq.com
 
 # ms
-FRIENDLY_USE_API = 350
+FRIENDLY_USE_API = 400
+FRIENDLY_DOWNLOAD = 1000
 
 # 导出页面结构
 PAGE_DIC = {}
@@ -16,6 +17,7 @@ CHILD_PAGE_TEMP = {
     "local_path": "",
     "page_name": "",
     "link_id": "",
+    "link_src": "",
     "child_pages": [],
     "inter_recursion": False,
     "inter_soft_page": False
